#include <vector>
#include <iostream>
#include <cassert>
#include <tuple>
#include <algorithm>
#include <fstream>

using namespace std;

const int M = (int)1e9 + 7;

int lgpow(int a, int b) {
    int answer = 1;
    while (b > 0) {
        if (b % 2 == 1) {
            answer = (long long)answer * a % M;
        }
        a = (long long)a * a % M;
        b /= 2;
    }
    return answer;
}

pair<vector<int>, vector<int>> precompute(const int &N) {
    vector<int> fact(N + 1), inverseFact(N + 1);
    fact[0] = 1;
    for (int i = 1; i <= N; i++) {
        fact[i] = (long long)fact[i - 1] * i % M;
    }
    inverseFact[N] = lgpow(fact[N], M - 2);
    for (int i = N - 1; i >= 0; i--) {
        inverseFact[i] = (long long)inverseFact[i + 1] * (i + 1) % M;
    }
    return make_pair(fact, inverseFact);
}

int main() {
	
	ifstream cin("scount.in");
	ofstream cout("scount.out");
    int N; cin >> N;
    vector<int> V(N);
    for (int &x : V) {
        cin >> x;
    }

    vector<int> freqs;
    sort(V.begin(), V.end());
    for (int i = 0; i < N; ) {
        int j = i + 1;
        while (j < N && V[i] == V[j]) {
            j++;
        }

        freqs.push_back(j - i);
        i = j;
    }

    vector<int> fact, inverseFact;
    tie(fact, inverseFact) = precompute(N);
    auto nCk = [&](int n, int k) -> int {
        assert(k <= n);
        return (long long)fact[n] * inverseFact[n - k] % M * inverseFact[k] % M;
    };

    sort(freqs.begin(), freqs.end());
    int answer = 1, pos = 0;
    for (int target = 1; target <= N; target++) {
        while (pos < (int)freqs.size() && freqs[pos] < target) {
            pos++;
        }

        int targetAnswer = 1;
        for (int i = pos; i < (int)freqs.size(); i++) {
            targetAnswer = (long long)targetAnswer * (nCk(freqs[i], target) + 1) % M;
        }
        if (pos < (int)freqs.size()) {
            targetAnswer = (targetAnswer - 1 + M) % M;
            answer = (answer + targetAnswer) % M;
        }
    }

    cout << answer << "\n";

    return 0;
}
